@@ -67,6 +67,9 @@ def accuracy(y_true, y_pred, sign=True):
 
     return R / (R + W)
 
+def simple_return(series):
+    ret = series[-1] / series[0] - 1
+    return ret
 
 def annual_return(series, period=365):
     """ Compute compouned annual return.
@@ -588,7 +591,7 @@ def get_accuracy_kpis(strategies, signals_df, under_returns_df):
 
 
 
-def get_kpi(price_df, default_metrics = [annual_return, annual_volatility, sharpe, calmar, mdd]):
+def get_kpi(price_df, default_metrics = [simple_return, annual_return, annual_volatility, sharpe, calmar, mdd]):
     nb_metrics = len(default_metrics)
     results = np.zeros([nb_metrics, len(price_df.columns)])
     # df = self.get_perf()
@@ -605,6 +608,5 @@ def get_kpi(price_df, default_metrics = [annual_return, annual_volatility, sharp
                 continue
         i += 1
 
-
     kpis_df = pd.DataFrame(results, columns=price_df.columns, index=[m.__name__ for m in default_metrics])
     return kpis_df
\ No newline at end of file
